package com.j2bugzilla.base;

import java.util.HashMap;
import java.util.Map;

import org.apache.xmlrpc.XmlRpcException;

/**
 * The {@code XmlExceptionHandler} provides a static utility method for translating
 * generic {@link XmlRpcException}s into subclasses of {@link BugzillaException}
 * to be handled by the client code.
 * 
 * @author Tom
 */
public final class XmlExceptionHandler {
	
	/**
	 * Private constructor to prevent instantiation.
	 */
	private XmlExceptionHandler() { }
	
	private static final Map<Integer, String> faultCodeMap = new HashMap<Integer, String>();
	
	{
		faultCodeMap.put(51, "The component you specified is not valid for this product");
		faultCodeMap.put(101, "The bug you attempted to retrieve does not exist");
		faultCodeMap.put(102, "You do not have permission to view this bug (Are you logged in?)");
		faultCodeMap.put(103, "The alias you specified is invalid");
		faultCodeMap.put(104, "One of the fields you specified for this bug is invalid");
		faultCodeMap.put(105, "No component was specified");
		faultCodeMap.put(106, "The specified product is invalid");
		faultCodeMap.put(107, "No summary was specified");
		faultCodeMap.put(108, "You do not have permission to edit this bug");
		faultCodeMap.put(504, "An invalid user was specified");
	}

	/**
	 * Translates a {@link XmlRpcException} into a subclass of {@link BugzillaException}
	 * @param exception An exception wrapping a known fault code of Bugzilla's interface
	 * @return A subclass of {@code BugzillaException}
	 */
	public static final BugzillaException handleFault(XmlRpcException exception) {
		
		String message = faultCodeMap.get(exception.code);
		if(message == null) { message = "An unknown error was encountered"; }
		return new BugzillaException(message, exception);
	}
	
}
